@@ -24,41 +24,28 @@ from sklearn.model_selection._validation import _score, cross_val_score
 from sklearn.utils.metaestimators import if_delegate_has_method, _safe_split
 from sklearn.utils.validation import check_is_fitted, check_X_y, check_random_state
 
-from featurebox.selection.mutibase import MutiBase
+from featurebox.selection.multibase import MultiBase
 from mgetool.tool import parallelize
 
 
-def _baf_single_fit(train, test, baf, estimator, X, y, scorer, random_state):
-    """"""
-    X_train, y_train = _safe_split(estimator, X, y, train)
-    X_test, y_test = _safe_split(estimator, X, y, test, train)
-    baf_i = clone(baf)
-    baf_i.random_state = random_state
-    baf_i.refit = True
-    baf_i._fit(X_train, y_train)
-    return baf_i.support_, _score(baf_i.estimator_, baf_i.transform(X_test, ), y_test, scorer), baf_i.score_
-
-
-class BackForward(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
+class BackForward(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MultiBase):
     """
     BackForward method to selected features.
+    
 
-    ``estimator``:
-        A supervised sklearn learning estimator with a ``_fit`` method that provides
-        information about feature importance either through a ``coef_``
-        attribute or through a ``feature_importances_`` attribute.
+    Attributes
+    ----------
+    n_feature_: int
+        The number of selected features finally.
 
-    ``n_type_feature_to_select``: int or None (default=None)
-        The number of feature to selection. If `None`, selection the features with best score.
+    support_: array of shape [n_feature]
+        The mask of selected features finally.
 
-    ``n_feature_``: int
-        The number of selected feature.
+    estimator_: object
+        The best model with the best features finally (refited with all data.).
 
-    ``support_``: array of shape [n_feature]
-        The mask of selected feature.
-
-    ``estimator_``: object
-        The external estimator _fit on the reduced dataset.
+    best_score_: float
+        Best score of best model of best features.
 
     Examples
     --------
@@ -72,28 +59,32 @@ class BackForward(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
     >>> bf = BackForward(svr,primary_feature=4, random_state=1)
     >>> new_x = bf.fit_transform(X,y)
     >>> bf.support_
-    array([False, False, False, False, False, False, False, False, False,
-           False,  True, False,  True])
+    array([False,  True,  True, False, False, False, False,  True])
 
     Examples
     --------
-    If score and predict is used, the refit could be set True and make sure the data is splited, due to the refit
-     used all data in fit() function.
+    If ``score`` and ``predict`` is used, the ``refit`` should be set True,
+    the refit used all data in ``fit`` function, that is, it is not test score/predict.
 
     >>> from sklearn.datasets import fetch_california_housing
     >>> from sklearn.svm import SVR
+    >>> from sklearn.model_selection import cross_val_score
     >>> X,y = fetch_california_housing(return_X_y=True)
     >>> X = X[:100]
     >>> y = y[:100]
     >>> svr= SVR()
-    >>> bf = BackForward(svr,primary_feature=4, random_state=1, refit=True)
-    >>> new_x = bf.fit_transform(X[:50],y[:50])
-    >>> test_score = bf.score(X[50:],y[50:])
-    ...
+    >>> bf = BackForward(svr,primary_feature=4, random_state=1, refit=True,cv=5)
+    >>> bf = bf.fit(X[:50],y[:50])
+    >>> bf.best_score_         # cv score
+    -3.0552830696940037
+    >>> train_score = bf.score(X[:50],y[:50])  # train score
+    >>> test_score = bf.score(X[-50:],y[-50:]) # test score in more data.
+    >>> np.mean(cross_val_score(bf.estimator_,X[:50,bf.support_],y[:50],cv=5)) # re cv_score in manually.
+    -3.0552830696940037
 
     Examples
     --------
-    If GridSearchCV, the refit could be set True and return the cv score.
+    If GridSearchCV, the refit should be set True and return the cv score.
 
     >>> from sklearn.datasets import fetch_california_housing
     >>> from sklearn.svm import SVR
@@ -102,57 +93,76 @@ class BackForward(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
     >>> X = X[:100]
     >>> y = y[:100]
     >>> svr= SVR()
-    >>> gd = model_selection.GridSearchCV(svr,param_grid={"C":[1,10]},n_jobs=1,cv=5)
-    >>> bf = BackForward(gd,primary_feature=4, random_state=1, refit=True)
-    >>> new_x = bf.fit_transform(X,y)
-    >>> test_score = bf.score(X,y)
-    ...
+    >>> gd = model_selection.GridSearchCV(svr,param_grid={"C":[1,10]},n_jobs=1)  # keep n_jobs=1 there.
+    >>> bf = BackForward(gd,primary_feature=4, random_state=1, refit=True,scoring="neg_root_mean_squared_error",cv=5)
+    >>> bf = bf.fit(X[:50],y[:50])
+    >>> bf.best_score_         # cv score
+    -0.5919173121895709
+    >>> train_score = bf.score(X[:50],y[:50])  # train score
+    >>> test_score = bf.score(X[-50:],y[-50:]) # test score in more data.
+    >>> bf.estimator_.best_score_ # re cv_score in manually.
+    -0.5919173121895709
     """
 
     def __init__(self, estimator: BaseEstimator, n_type_feature_to_select: int = None, primary_feature: int = None,
-                 muti_grade: int = 2, muti_index: List = None, refit=False, cv=5, min_type_feature_to_select: int = 3,
-                 must_index: List = None, tolerant: float = 0.01, verbose: int = 0, random_state: int = None):
+                 multi_grade: int = 2, multi_index: List = None, refit=False, cv=5, min_type_feature_to_select: int = 3,
+                 must_index: List = None, tolerant: float = 0.01, verbose: int = 1, random_state: int = None,
+                 scoring: str = None):
         """
 
         Parameters
         ----------
-        estimator:sklearn.estimator
-            sklearn.estimator
+        estimator : estimator object
+            This is assumed to implement the scikit-learn estimator interface.
+            A supervised sklearn learning estimator with ``fit`` method.
         n_type_feature_to_select:int
-            force select number max
+            The max number of feature to selection. If ``None``, select the features with best score.
         min_type_feature_to_select:int
-            force select number min
+            force select number min.
         primary_feature:int
-             primary features to start loop, default n_features//2.
-        muti_grade: int
-            group number
-        muti_index:
-            group index
+            primary features to start loop, default initial n_features//2.
+        multi_grade: int
+            group number.
+        multi_index:
+            group index.
         must_index:
-            must selection index
+            must selection index.
         tolerant:
             tolerant for rank compare.
         verbose:int
-            print or not
+            print or not.
         random_state:int
-            random_state
-        refit:refit
+            random_state.
+        refit:bool
             refit or not. if refit, the model would use all data.
+        scoring:None,str
+            scoring method name.
         """
-        super().__init__(muti_grade=muti_grade, muti_index=muti_index, must_index=must_index)
-        if hasattr(estimator, "max_features") and refit:
-            print("For estimator with 'max_features' attribute, the 'max_features' would changed with "
-                  "each sub-data. that is, The 'refit estimator' which with fixed 'max_features' could be with different performance.\n"
-                  "Please change and define 'max_features' (with other parameters fixed) by manual testing after Backforward!!!!\n"
-                  "Please change and define 'max_features' (with other parameters fixed) by manual testing after Backforward!!!!",
-                  )
-        elif isinstance(estimator, BaseSearchCV) and hasattr(estimator.estimator, "max_features") and refit:
-            print("For estimator in SearchCV with 'max_features' attribute, the 'max_features' would changed with "
-                  "each sub-data. that is, The 'refit estimator' which with fixed 'max_features' could be with different performance.\n"
-                  "Please change and define 'max_features' (with other parameters fixed) by manual testing after Backforward!!!!\n"
-                  "Please change and define 'max_features' (with other parameters fixed) by manual testing after Backforward!!!!",
-                  )
+        super().__init__(multi_grade=multi_grade, multi_index=multi_index, must_index=must_index)
+        if any((hasattr(estimator, "max_features") and refit,
+                isinstance(estimator, BaseSearchCV) and hasattr(estimator.estimator, "max_features") and refit)):
+            print("For estimator with 'max_features' attribute, the 'max_features' would changed with each sub-data. \n"
+                  "Please change and define 'max_features' by manual testing after Backforward!\n")
+        if refit:
+            if isinstance(estimator, BaseSearchCV) and estimator.refit is True:
+                warnings.warn(
+                    "\nThe self.estimator_ :{} would used all the X, y data if refit! \n"
+                    "Please be careful with the 'score' and 'predict' if use, which are 'train' score/predict if inputs not changed.\n"
+                    "Check 'self.estomator_' to get CV result, such as 'self.estomator_.best_score_' for evaluation instead.".format(
+                        estimator.__class__.__name__), UserWarning)
+            else:
+                warnings.warn(
+                    "\nThe self.estimator_ :{} would used all the X, y data if refit! \n"
+                    "Please be careful with the 'score' and 'predict' if use, which are 'train' score/predict if inputs not changed.\n"
+                    "Use 'cross_val_score(self.estimator_,X[:, self.support_],y)' for evaluation instead.".format(
+                        estimator.__class__.__name__), UserWarning)
+
+        if isinstance(estimator, BaseSearchCV):
+            estimator.scoring = scoring
+            estimator.cv = cv
+        self.scoring = scoring
         self.estimator = estimator
+
         self.n_type_feature_to_select = n_type_feature_to_select
         self.primary_feature = primary_feature
         self.verbose = verbose
@@ -205,7 +215,7 @@ class BackForward(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
                 if self.verbose > 0:
                     print("Fitting estimator with {} feature {}".format(len(slice10), best0))
                 self.score_.append((tuple(slice10), best0))
-            return slice10
+            return slice10, best0
 
         def sub_slice(slice10):
             best0 = score(slices=slice10)
@@ -263,17 +273,12 @@ class BackForward(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
                 data_x0 = x0[:, slices]
 
                 if hasattr(self.estimator, "max_features"):
-                    if self.estimator.max_features > data_x0.shape[1]:
-                        estimator_ = clone(self.estimator)
-                        estimator_.max_features = data_x0.shape[1]
-                    else:
-                        estimator_ = estimator
+                    estimator_ = clone(self.estimator)
+                    estimator_.max_features = data_x0.shape[1]  # force to data feature size.
+
                 elif isinstance(self.estimator, BaseSearchCV) and hasattr(self.estimator.estimator, "max_features"):
-                    if self.estimator.estimator.max_features > data_x0.shape[1]:
-                        estimator_ = clone(self.estimator)
-                        estimator_.estimator.max_features = data_x0.shape[1]
-                    else:
-                        estimator_ = estimator
+                    estimator_ = clone(self.estimator)
+                    estimator_.estimator.max_features = data_x0.shape[1]  # force to data feature size.
                 else:
                     estimator_ = estimator
 
@@ -282,7 +287,7 @@ class BackForward(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
                 if hasattr(estimator_, 'best_score_') or isinstance(estimator_, BaseSearchCV):
                     score0 = np.mean(estimator_.best_score_)
                 else:
-                    score0 = np.mean(cross_val_score(estimator_, data_x0, y0, cv=self.cv))
+                    score0 = np.mean(cross_val_score(estimator_, data_x0, y0, cv=self.cv, scoring=self.scoring))
 
             return score0
 
@@ -290,18 +295,19 @@ class BackForward(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
 
         self.score_ = []
         x, y = check_X_y(x, y, "csc")
-        assert all((self.check_must, self.check_muti)) in [True, False]
+        assert all((self.check_must, self.check_multi)) in [True, False]
         # Initialization
-        if self.check_muti:
-            n_feature = (self.muti_index[1] - self.muti_index[0]) // self.muti_grade + self.muti_index[0]
+        if self.check_multi:
+            n_feature = (self.multi_index[1] - self.multi_index[0]) // self.multi_grade + self.multi_index[0]
         else:
             n_feature = x.shape[1]
         if self.primary_feature is None:
             primary_feature = n_feature // 2
         else:
             primary_feature = self.primary_feature
+        assert primary_feature < n_feature, "Too large for primary_feature."
 
-        feature_list = list(range(x.shape[1]))
+        feature_list = list(range(n_feature))
         fold_feature_list = self.feature_fold(feature_list)
 
         ran = check_random_state(self.random_state)
@@ -310,27 +316,23 @@ class BackForward(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
         slice2 = list(set(fold_feature_list) - set(slice1))
         ran.shuffle(slice2)
 
-        slice1 = add_slice(slice1, slice2)
+        slice1, best = add_slice(slice1, slice2)
         if isinstance(self.n_type_feature_to_select, int) and len(slice1) > self.n_type_feature_to_select:
             slice1, best = sub_slice_force(slice1)
 
         slice1.sort()
-        select_feature = self.feature_unfold(slice1)
-        su = np.zeros(x.shape[1], dtype=np.bool)
-        su[select_feature] = 1
-        self.support_ = su
+        select_feature = np.array(self.feature_unfold(slice1))
+        sup = np.zeros(x.shape[1], dtype=np.bool)
+        sup[select_feature] = 1
+        self.best_score_ = best
+        self.support_ = sup
         self.estimator_ = clone(self.estimator)
+
         if self.refit:
-            if not hasattr(self.estimator_, 'best_score_'):
-                warnings.warn(UserWarning(
-                    "The self.estimator_ :{} used all the X,y data.".format(self.estimator_.__class__.__name__),
-                    "please be careful with the later 'score' and 'predict'."))
-            if hasattr(self.estimator_, 'best_score_') and hasattr(self.estimator_, "refit") \
-                    and self.estimator_.refit is True:
-                warnings.warn(UserWarning(
-                    "The self.estimator_ :{} used all the X,y data.".format(self.estimator_.__class__.__name__),
-                    "please be careful with the later 'score' and 'predict'."))
-            self.estimator_.max_features = select_feature.shape[0]
+            if hasattr(self.estimator, "max_features"):
+                self.estimator_.max_features = select_feature.shape[0]
+            elif isinstance(self.estimator, BaseSearchCV) and hasattr(self.estimator.estimator, "max_features"):
+                self.estimator_.estimator.max_features = select_feature.shape[0]
             self.estimator_.fit(x[:, select_feature], y)
         self.n_feature_ = len(select_feature)
 
@@ -355,7 +357,7 @@ class BackForward(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
         return self.estimator_.predict(self.transform(X))
 
     @if_delegate_has_method(delegate='estimator_')
-    def score(self, X, y):
+    def score(self, X, y, scoring=None):
         """Reduce X to the selected feature and then return the score of the underlying estimator.
         Only available ``refit=True``.
 
@@ -366,15 +368,38 @@ class BackForward(BaseEstimator, MetaEstimatorMixin, SelectorMixin, MutiBase):
 
         y : array of shape [n_samples]
             The target values.
+
+        scoring : str, callable, default=None
+            Strategy to evaluate the performance of the cross-validated model on
+            the test set.
+
+            If `scoring` represents a single score, one can use:
+            a single string (see :ref:`scoring_parameter`)
+
+            The score defined by ``scoring`` if provided, and the
+            ``estimator_.score`` method otherwise else raise error.
         """
         check_is_fitted(self, 'estimator_')
-        return self.estimator_.score(self.transform(X), y)
+        scoring = scoring if scoring is not None else self.scoring
+        scorer = check_scoring(self.estimator_, scoring=scoring, allow_none=False)
+        return scorer(self.estimator_, self.transform(X), y)
 
     def _get_support_mask(self):
         check_is_fitted(self, 'support_')
         return self.support_
 
 
+def _baf_single_fit(train, test, baf, estimator, X, y, scorer, random_state):
+    """"""
+    X_train, y_train = _safe_split(estimator, X, y, train)
+    X_test, y_test = _safe_split(estimator, X, y, test, train)
+    baf_i = clone(baf)
+    baf_i.random_state = random_state
+    baf_i.refit = True
+    baf_i._fit(X_train, y_train)
+    return baf_i.support_, _score(baf_i.estimator_, baf_i.transform(X_test, ), y_test, scorer), baf_i.score_
+
+
 def _multi_time_fit(random_state, baf, X, y, scorer):
     """"""
     baf_i = clone(baf)
@@ -387,33 +412,24 @@ def _multi_time_fit(random_state, baf, X, y, scorer):
 class BackForwardStable(MetaEstimatorMixin, SelectorMixin, BaseEstimator):
     """
     BackForwardStable.
-    Run with different order for more Stable (Not guaranteed).
+    Run with different order for more Stable (Just for test).
 
-    ``estimator`` : object
-        A supervised learning estimator with a ``_fit`` method that provides
-        information about feature importance either through a ``coef_``
-        attribute or through a ``feature_importances_`` attribute.
-
-    ``scoring`` : string, callable or None, optional, (default=None)
-        A string (see model evaluation documentation) or
-        a scorer callable object / function with signature
-        ``scorer(estimator, X, y)``.
-
-    ``verbose`` : int, (default=0)
-        Controls verbosity of output.
-
-    ``n_feature_`` : int
+    Attributes
+    ----------
+    n_feature_ : int
         The number of selected feature with cross-validation.
 
-    ``support_`` : array of shape [n_feature]
+    support_ : array of shape [n_feature]
         The mask of selected feature.
 
-    ``estimator_`` : object
-        The external estimator _fit on the reduced dataset.
+    estimator_ : object
+        The model with the best features finally (refited with all data.).
 
-   ``n_jobs`` : int or None
-        Number of cores to run in parallel while fitting across folds.
-        ``None`` means 1 and ``-1`` means using all processors.
+    best_score_: float
+        Best score of best model of best features.
+
+    Examples
+    --------
 
     >>> from sklearn.datasets import fetch_california_housing
     >>> from sklearn.svm import SVR
@@ -421,13 +437,12 @@ class BackForwardStable(MetaEstimatorMixin, SelectorMixin, BaseEstimator):
     >>> X = X[:100]
     >>> y = y[:100]
     >>> svr= SVR()
-    >>> bf = BackForwardStable(svr,primary_feature=9,  random_state=1)
+    >>> bf = BackForwardStable(svr,primary_feature=3,  random_state=1)
     >>> new_x = bf.fit_transform(X,y)
     >>> bf.support_
-    array([False, False, False, False, False, False, False, False, False,
-           False,  True, False,  True])
-    >>> bf.score_
-    0.642826382278419
+    array([False,  True, False, False, False,  True,  True, False])
+    >>> bf.best_score_
+    -0.09122826477472024
 
     If score and predict is used, the refit could be set True and make sure the data is splited, due to the refit
     used all data in fit() function.
@@ -440,7 +455,8 @@ class BackForwardStable(MetaEstimatorMixin, SelectorMixin, BaseEstimator):
     >>> svr= SVR()
     >>> bf = BackForwardStable(svr,primary_feature=4, random_state=1, refit=True)
     >>> new_x = bf.fit_transform(X[:50],y[:50])
-    >>> test_score = bf.score(X[50:],y[50:])
+    >>> train_score = bf.score(X[50:],y[50:])
+    >>> cv_score = bf.best_score_
     ...
 
     If GridSearchCV, the refit could be set True and return the cv score.
@@ -455,46 +471,48 @@ class BackForwardStable(MetaEstimatorMixin, SelectorMixin, BaseEstimator):
     >>> gd = model_selection.GridSearchCV(svr,param_grid={"C":[1,10]},n_jobs=1,cv=5)
     >>> bf = BackForward(gd,primary_feature=4, random_state=1, refit=True)
     >>> new_x = bf.fit_transform(X,y)
-    >>> test_score = bf.score(X,y)
     ...
     """
 
     def __init__(self, estimator: BaseEstimator, n_type_feature_to_select: int = None,
                  min_type_feature_to_select: int = 3,
-                 primary_feature: int = None, muti_grade: int = 2, muti_index: List = None,
+                 primary_feature: int = None, multi_grade: int = 2, multi_index: List = None,
                  must_index: List = None, verbose: int = 0, random_state: int = None,
-                 times: int = 5, scoring: str = "r2", n_jobs: int = None, refit=False):
+                 tolerant: float = 0.001,
+                 times: int = 5, scoring: str = None, n_jobs: int = None, refit=False):
         """
 
         Parameters
         ----------
-        estimator:sklearn.estimator
-            sklearn.estimator
+        estimator : estimator object
+            This is assumed to implement the scikit-learn estimator interface.
+            A supervised sklearn learning estimator with ``fit`` method.
         n_type_feature_to_select:int
-            force select number max
+            The max number of feature to selection. If ``None``, select the features with best score.
         min_type_feature_to_select:int
-            force select number min
+            force select number min.
         primary_feature:int
-             expectation select number
-        muti_grade: int
-            group number
-        muti_index: list
-            group index
-        must_index: list
-            must selection index
+            primary features to start loop, default initial n_features//2.
+        multi_grade: int
+            group number.
+        multi_index:
+            group index.
+        must_index:
+            must selection index.
+        tolerant:
+            tolerant for rank compare.
+        verbose:int
+            print or not.
         random_state:int
-            random_state
-        scoring : string, callable or None, optional, (default=None)
-            A string (see model evaluation documentation) or
-            a scorer callable object / function with signature
-            ``scorer(estimator, X, y)``.
-        verbose : int, (default=0)
-            Controls verbosity of output.
+            random_state.
+        refit:bool
+            refit or not. if refit, the model would use all data.
         n_jobs : int or None
             Number of cores to run in parallel while fitting across folds.
             ``None`` means 1 and ``-1`` means using all processors.
-        refit:
-            False, with refit, the model would used all data.
+        scoring: None,str
+            scoring method.
+
         """
         if isinstance(estimator, BaseSearchCV):
             warnings.warn("The 'estimator' of BackForwardStable not suggested BaseSearchCV, "
@@ -508,12 +526,13 @@ class BackForwardStable(MetaEstimatorMixin, SelectorMixin, BaseEstimator):
         self.n_type_feature_to_select = n_type_feature_to_select
         self.min_type_feature_to_select = min_type_feature_to_select
         self.primary_feature = primary_feature
-        self.muti_grade = muti_grade
-        self.muti_index = muti_index
+        self.multi_grade = multi_grade
+        self.multi_index = multi_index
         self.must_index = must_index
         self.score_ = []
         self.random_state = random_state
         self.refit = refit
+        self.tolerant = tolerant
 
     def fit(self, X, y, groups=None):
         """Fit the baf model and automatically tune the number of selected feature.
@@ -542,8 +561,8 @@ class BackForwardStable(MetaEstimatorMixin, SelectorMixin, BaseEstimator):
                           n_type_feature_to_select=self.n_type_feature_to_select,
                           min_type_feature_to_select=self.min_type_feature_to_select,
                           verbose=self.verbose, primary_feature=self.primary_feature,
-                          muti_grade=self.muti_grade, muti_index=self.muti_index,
-                          must_index=self.must_index, random_state=ran)
+                          multi_grade=self.multi_grade, multi_index=self.multi_index,
+                          must_index=self.must_index, random_state=ran, tolerant=self.tolerant)
         rans = ran.randint(0, 1000, self.times)
 
         func = partial(_multi_time_fit, baf=baf, X=X, y=y, scorer=scorer)
@@ -552,26 +571,17 @@ class BackForwardStable(MetaEstimatorMixin, SelectorMixin, BaseEstimator):
 
         support, scores, score_step = zip(*scores)
         best_support = support[np.argmax(scores)]
-        best_score = max(scores)
+        best_score = scores[np.argmax(scores)]
         # Re-execute an elimination with best_k over the whole set
 
         # Set final attributes
         self.support_step = score_step
         self.support_ = best_support
-        self.score_ = best_score
+        self.best_score_ = best_score
         self.estimator_ = clone(self.estimator)
         if self.refit:
-            if not hasattr(self.estimator_, 'best_score_'):
-                warnings.warn(UserWarning(
-                    "The self.estimator_ :{} used all the X,y data.".format(self.estimator_.__class__.__name__),
-                    "please be careful with the later 'score' and 'predict'."))
-            if hasattr(self.estimator_, 'best_score_') and hasattr(self.estimator_, "refit") \
-                    and self.estimator_.refit is True:
-                warnings.warn(UserWarning(
-                    "The self.estimator_ :{} used all the X,y data.".format(self.estimator_.__class__.__name__),
-                    "please be careful with the later 'score' and 'predict'."))
             if hasattr(self.estimator_, "max_features"):
-                self.estimator_.max_features = np.array(self.support_).shape[0]
+                self.estimator_.max_features = np.sum(self.support_)
             self.estimator_.fit(X[:, self.support_], y)
         self.n_feature_ = np.count_nonzero(support)
         return self
